<?php

namespace Drp\UserManagement\Http\Controllers\Auth;

use Drp\UserManagement\Contracts\ManagedUser;
use Drp\UserManagement\UserCreator;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Foundation\Auth\ResetsPasswords;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Http\RedirectResponse;
use Illuminate\Routing\Controller;

class LoginTokenController extends Controller
{
    use ResetsPasswords, AuthorizesRequests, ValidatesRequests;

    /**
     * @var \Drp\UserManagement\Http\Controllers\Auth\UserCreator
     */
    private $userCreator;

    /**
     * @var \Drp\UserManagement\Http\Controllers\Auth\User
     */
    private $user;

    public function __construct(UserCreator $userCreator, ManagedUser $user)
    {
        $this->userCreator = $userCreator;
        $this->user = $user;
    }

    public function sendLoginToken(ManagedUser $user): RedirectResponse
    {
        if ($user->password !== null) {
            flash()->error(trans('userManagement::users.account-already-setup'));
            return redirect()
                ->back();
        }

        $this->userCreator->reIssueLoginCode($user);

        flash()->success(trans('userManagement::users.login-sent'));
        return redirect()
            ->back();
    }

    /**
     * @return View|RedirectResponse
     */
    public function firstLogin(string $token)
    {
        try {
            $user = $this->user->getByFirstLoginToken($token);

            if ($user->loginExpiry()->isPast()) {
                return view('userManagement::auth.expired');
            }

            auth()->login($user);

            return redirect()->route('account.setup');
        } catch (ModelNotFoundException $e) {
            return abort(500);
        }
    }
}
