<?php

namespace Drp\UserManagement\Mail;

use Drp\UserManagement\Events\UserCreatedWithLoginCode;
use Illuminate\Bus\Queueable;
use Illuminate\Mail\Mailable;
use Illuminate\Queue\SerializesModels;
use Illuminate\Support\Facades\Mail;

class FirstTimeAccountSetup extends Mailable
{
    use Queueable, SerializesModels;

    /**
     * @var string
     */
    public $expiry;

    /**
     * @var string
     */
    public $token;

    public function __construct(?string $expiry = null, ?string $token = null)
    {
        $this->expiry = $expiry;
        $this->token = $token;
    }

    public function handle(UserCreatedWithLoginCode $event): void
    {
        Mail::to($event->user)->send(
            new static(
                $event->user->loginExpiry()->format('jS F Y H:i'),
                $event->user->loginToken()
            )
        );
    }

    public function build(): FirstTimeAccountSetup
    {
        return $this
            ->subject(config('app.name') . ': Account setup')
            ->markdown('userManagement::emails.account.setup');
    }
}
