<?php

namespace Drp\UserManagement\Test\Feature;

use Carbon\Carbon;
use Drp\UserManagement\Events\AccountActivated;
use Drp\UserManagement\Events\UserCreatedWithLoginCode;
use Drp\UserManagement\Mail\FirstTimeAccountSetup;
use Drp\UserManagement\Test\TestCase;
use Drp\UserManagement\User;
use Illuminate\Support\Facades\Mail;
use Drp\UserManagement\Events\AccountActivated as AccountActivatedEvent;
use Drp\UserManagement\Mail\AccountActivation as AccountActivatedMail;

/**
 * Class NotificationsTest
 * @package Drp\UserManagement\Test\Feature
 */
class NotificationsTest extends TestCase
{
    /**
     * @test
     */
    public function the_login_link_is_sent_to_new_users()
    {
        Mail::fake();

        $user = new User([
            'email' => 'test@user.com',
            'login_link_expiry' => Carbon::create(2017, 01, 01, 12, 00),
            'first_login_token' => 'TOKEN'
        ]);
        event(new UserCreatedWithLoginCode($user));

        Mail::assertSent(FirstTimeAccountSetup::class, function ($mail) use ($user) {
            $this->assertTrue($mail->hasTo($user->email));
            $this->assertEquals('1st January 2017 12:00', $mail->expiry);
            $this->assertEquals('TOKEN', $mail->token);
            return true;
        });
    }

    /**
     * @test
     */
    public function the_activation_link_is_sent_to_new_users()
    {
        Mail::fake();

        $user = new User([
            'email' => 'test@user.com',
        ]);
        event(new AccountActivatedEvent($user));

        Mail::assertSent(AccountActivatedMail::class, function ($mail) use ($user) {
            $this->assertTrue($mail->hasTo($user->email));
            return true;
        });
    }
}
